package com.miaxis.app.controller.tms;


import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.tms.dto.*;
import com.miaxis.tms.service.ITmsCoachInfoService;
import com.miaxis.tms.vo.TmsCoachInfoQRVo;
import com.miaxis.tms.vo.TmsCoachInfoVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 学员基本信息表 前端控制器
 * </p>
 *
 * @since 2021-03-09
 */
@RestController
@Api(tags = "【app-教练员】")
@RequestMapping(Constants.OPEN_PREFIX + "/tms/coachInfo")
public class TmsCoachInfoController extends BaseController {

    @Autowired
    private ITmsCoachInfoService coachInfoService;


    /**
     * 获取用户id获取详细信息
     */
    @GetMapping("/getCoachInfo")
    @ApiOperation("获取教练员详细信息")
    public Response<TmsCoachInfoVo> getCoachInfo(TmsCoachInfoIdDTO coaIdDto) {
        return Response.success(coachInfoService.getCoachInfoById(coaIdDto));
    }


    /**
     * 获取教练员生成二维码信息
     */
    @GetMapping("/getCoachQrInfo")
    @ApiOperation("获取教练员生成二维码信息")
    public Response<TmsCoachInfoQRVo> getCoachQrInfo(TmsCoachInfoIdDTO coaIdDto) {
        TmsCoachInfoVo coachInfoVo = coachInfoService.getCoachInfoById(coaIdDto);
        TmsCoachInfoQRVo qrVo = new TmsCoachInfoQRVo();
        BeanUtils.copyProperties(coachInfoVo,qrVo);
        return Response.success(qrVo);
    }

    /**
     * 教练登录测试
     */
    @GetMapping("/coachInfoLogin")
    @ApiOperation("教练登录")
    public Response<TmsCoachInfoVo> coachInfoLogin(TmsCoachInfoDTO coaDto) {
        TmsCoachInfoVo coachInfo = coachInfoService.getCoachBylogin(coaDto);
        if(coachInfo==null) {
            Response response = new Response(502,"用户不存在或用户密码错误");
            return response;

        }
        return Response.success(coachInfoService.getCoachBylogin(coaDto));
    }


    /**
     * 教练修改密码
     */
    @PutMapping("/updateCoachPassword")
    @ApiOperation("教练修改密码")
    public Response updateCoachPassword(TmsCoachInfoPwDTO coaPwDto) {
        return coachInfoService.updateCoachPassword(coaPwDto);
    }


    /**
     * 教练与微信号绑定
     */
    @PutMapping("/bindCoachOpenid")
    @ApiOperation("绑定教练与微信号")
    public Response bindCoachOpenid(TmsCoachInfoBindDTO coachInfoBindDTO) {
        return coachInfoService.bindCoachOpenid(coachInfoBindDTO);
    }



    /**
     * 解绑教练与微信号
     */
    @PutMapping("/unBindCoachOpenid")
    @ApiOperation("解绑教练与微信号")
    public Response unBindCoachOpenid(TmsCoachInfoDTO coachInfoDTO) {
        return coachInfoService.unBindCoachOpenid(coachInfoDTO);
    }

    /**
     * 根据教练身份证与手机号获取教练管家密码
     */
    @GetMapping("/getPasswordByCoachIdcard")
    @ApiOperation("根据教练身份证与手机号获取教练管家密码")
    public Response getPasswordByCoachIdcard(TmsIdcardPhoneDTO idcardPhoneDTO) {
        return Response.success(coachInfoService.getPasswordByCoachIdcard(idcardPhoneDTO));
    }

}

