package com.miaxis.app.controller.tms;


import com.miaxis.coach.domain.CoachManySchool;
import com.miaxis.coach.service.ICoachManySchoolService;
import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.tms.dto.*;
import com.miaxis.tms.service.ITmsStudentInfoService;
import com.miaxis.tms.vo.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.sql.SQLException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 学员基本信息表 前端控制器
 * </p>
 *
 * @since 2021-03-09
 */
@RestController
@Api(tags = "【app-教练端-学员接口】")
@RequestMapping(Constants.OPEN_PREFIX + "/tms/coachInfo")
public class TmsStudentInfoController extends BaseController {

    @Autowired
    private ITmsStudentInfoService studentInfoService;

    @Autowired
    private ICoachManySchoolService coachManySchoolService;


    /**
     * 查询我的学员信息列表(查询用)
     */
    @GetMapping("/allStudentInfoList")
    @ApiOperation("预报地区-查询我的学员信息列表(查询用)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "当前页码", dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize", value = "每页数据量", dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<TmsStudentInfoVo> allStudentInfoList(@ModelAttribute TmsAllStudentInfoDTO allStudentInfoDTO) {
        startPage();
        List<TmsStudentInfoVo> stuInfoList = studentInfoService.getTmsAllStudentInfoList(allStudentInfoDTO);
        return toResponsePageInfo(stuInfoList);
    }


    /**
     * 查询在校学员信息列表(查询用)
     */
    @GetMapping("/allSchoolStudentInfoList")
    @ApiOperation("预报地区-查询在校学员信息列表(查询用)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "当前页码", dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize", value = "每页数据量", dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<TmsStudentInfoVo> allSchoolStudentInfoList(@ModelAttribute TmsAllStudentInfoDTO allStudentInfoDTO) {
        if(allStudentInfoDTO.getCoachId()!=null) {
            CoachManySchool coachManySchool = coachManySchoolService.getById(allStudentInfoDTO.getCoachId());
            if(coachManySchool!=null) {
                allStudentInfoDTO.setSchoolId(coachManySchool.getSchoolIds());
            }
        }
        allStudentInfoDTO.setCoachId(null);
        startPage();
        List<TmsStudentInfoVo> stuInfoList = studentInfoService.getTmsAllStudentInfoList(allStudentInfoDTO);
        return toResponsePageInfo(stuInfoList);
    }



    /**
     * 查询学员信息列表
     */
    @GetMapping("/list")
    @ApiOperation("查询学员信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "当前页码", dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize", value = "每页数据量", dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<TmsStudentInfoVo> list(@ModelAttribute TmsStudentInfoDTO studentInfoDTO) {
        if(studentInfoDTO.getCoachId()!=null) {
            CoachManySchool coachManySchool = coachManySchoolService.getById(studentInfoDTO.getCoachId());
            if(coachManySchool!=null) {
                studentInfoDTO.setSchoolId(coachManySchool.getSchoolIds());
            }
        }
        studentInfoDTO.setCoachId(null);
        startPage();
        List<TmsStudentInfoVo> stuInfoList = studentInfoService.getTmsStudentInfoList(studentInfoDTO);
        return toResponsePageInfo(stuInfoList);
    }


    /**
     * 查询我的学员信息列表
     */
    @GetMapping("/myList")
    @ApiOperation("查询我的学员信息列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "当前页码", dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize", value = "每页数据量", dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<TmsStudentInfoVo> myList(@ModelAttribute TmsStudentInfoDTO studentInfoDTO) {
        startPage();
        List<TmsStudentInfoVo> stuInfoList = studentInfoService.getTmsMyStudentInfoList(studentInfoDTO);
        return toResponsePageInfo(stuInfoList);
    }

    /**
     * 查询我的学员预报名列表
     */
    @GetMapping("/myStudentTempList")
    @ApiOperation("预报地区-查询我的学员预报名列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "当前页码", dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize", value = "每页数据量", dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<TmsStudentInfoTempVo> myStudentTempList(@ModelAttribute TmsStudentInfoTempDTO studentInfoTempDTO) {
        startPage();
        List<TmsStudentInfoTempVo> stuInfoTempList = studentInfoService.getTmsMyStudentInfoTempList(studentInfoTempDTO);
        return toResponsePageInfo(stuInfoTempList);
    }

    /**
     * 查询学员预报名列表
     */
    @GetMapping("/studentTempList")
    @ApiOperation("预报地区-查询学员预报名列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "当前页码", dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize", value = "每页数据量", dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<TmsStudentInfoTempVo> studentTempList(@ModelAttribute TmsStudentInfoTempDTO studentInfoTempDTO) {
        if(studentInfoTempDTO.getCoachId()!=null) {
            CoachManySchool coachManySchool = coachManySchoolService.getById(studentInfoTempDTO.getCoachId());
            if(coachManySchool!=null) {
                studentInfoTempDTO.setSchoolId(coachManySchool.getSchoolIds());
            }
        }
        studentInfoTempDTO.setCoachId(null);
        startPage();
        List<TmsStudentInfoTempVo> stuInfoTempList = studentInfoService.getTmsStudentInfoTempList(studentInfoTempDTO);
        return toResponsePageInfo(stuInfoTempList);
    }






    /**
     * 根据学员id获取详细信息
     */
    @GetMapping("/getTmsStudentInfoById")
    @ApiOperation("根据ID获取学员详细信息（无时间点）")
    public Response<TmsStudentInfoIdVo> getTmsStudentInfoById(TmsStudentInfoIdDTO studentInfoIdDTO) {
        return Response.success(studentInfoService.getTmsStudentInfoById(studentInfoIdDTO));
    }

    /**
     * 根据预约报名学员id获取详细信息
     */
    @GetMapping("/getTmsStudentInfoTempById")
    @ApiOperation("根据ID获取预约报名学员详细信息（无时间点）")
    public Response<TmsStudentInfoIdVo> getTmsStudentInfoTempById(TmsStudentInfoIdDTO studentInfoIdDTO) {
        return Response.success(studentInfoService.getTmsStudentInfoTempById(studentInfoIdDTO));
    }


    /**
     * 温州根据学员id获取详细信息
     */
    @GetMapping("/getTmsStudentInfoApplyById")
    @ApiOperation("温州等根据ID获取学员员详细信息（需要报名时间）")
    public Response<TmsStudentInfoIdVo> getTmsStudentInfoApplyById(TmsStudentInfoApplyIdDTO studentInfoApplyIdDTO) {
        return Response.success(studentInfoService.getTmsStudentInfoApplyById(studentInfoApplyIdDTO));
    }





    /**
     * 根据学员id学员训练照片
     */
    @GetMapping("/getTmsLogFaceListByStuId")
    @ApiOperation("根据学员id学员训练照片")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "当前页码", dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize", value = "每页数据量", dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<TmsLogFaceVo> getTmsLogFaceListByStuId(TmsStudentInfoIdDTO studentInfoIdDTO) {
        startPage();
        List<TmsLogFaceVo> logFaceListList = studentInfoService.getTmsLogFaceListByStuId(studentInfoIdDTO);
        return toResponsePageInfo(logFaceListList);
    }


    /**
     * 根据学员id获取签到签退列表
     */
    @GetMapping("/getTmsSignListByStuId")
    @ApiOperation("根据学员id获取签到签退列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "当前页码", dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize", value = "每页数据量", dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<TmsSignVo> getTmsSignListByStuId(TmsStudentInfoIdDTO studentInfoIdDTO) {
        startPage();
        List<TmsSignVo> signList= studentInfoService.getTmsSignListByStuId(studentInfoIdDTO);
        return toResponsePageInfo(signList);
    }


    /**
     * 根据学员ID绑定APP教练员(极速驾培调用)
     */
    @GetMapping("/updateStudentAppCoachIdById")
    @ApiOperation("根据学员ID绑定APP教练员")
    public Response updateStuAppCoachIdById(TmsStudentInfoQrDTO studentInfoQrDTO) {
        return Response.success(studentInfoService.upStuAppCoachIdById(studentInfoQrDTO));
    }





    /**
     * 根据驾校ID 报名统计
     */
    @GetMapping("/getStatisticsStuCountBySchoolId")
    @ApiOperation("根据驾校ID 报名统计")
    public Response getStatisticsStuCountBySchoolId(TmsBmDTO bmDTO) {
        try {
            return Response.success(studentInfoService.getStatisticsStuCountBySchoolId(bmDTO));
        } catch (SQLException e) {
            e.printStackTrace();
            Response response = new Response(500,"系统开小差，请重试。");
            return response;
        }
    }


    /**
     * 根据驾校ID查询学员每日报名数
     */
    @GetMapping("/getEveryDayStuCountBySchoolId")
    @ApiOperation("根据驾校ID查询学员每日报名数")
    public ResponsePageInfo getEveryDayStuCountBySchoolId(@ModelAttribute TmsBmDayListDTO dayListDTO) {
        List<TmsBmCountVo> list = studentInfoService.getEveryDayStuCountBySchoolId(dayListDTO);
        ResponsePageInfo<TmsBmCountVo> reusltList = toResponsePageInfo(list);
        Map<String,Integer> map = new HashMap<String,Integer>();
        int total = list.stream().mapToInt(TmsBmCountVo::getStuCount).sum();
        map.put("total",total);
        reusltList.setData(map);
        return reusltList;
    }

    /**
     * 根据驾校ID查询学员每月报名数
     */
    @GetMapping("/getEveryMonthStuCountBySchoolId")
    @ApiOperation("根据驾校ID查询学员每月报名数")
    public ResponsePageInfo getEveryMonthStuCountBySchoolId(@ModelAttribute TmsBmMonthListDTO monthListDTO) {
        List<TmsBmCountVo> list = studentInfoService.getEveryMonthStuCountBySchoolId(monthListDTO);
        ResponsePageInfo<TmsBmCountVo> reusltList = toResponsePageInfo(list);
        Map<String,Integer> map = new HashMap<String,Integer>();
        int total = list.stream().mapToInt(TmsBmCountVo::getStuCount).sum();
        map.put("total",total);
        reusltList.setData(map);
        return reusltList;
    }

    /**
     * 根据驾校ID查询学员每年报名数
     */
    @GetMapping("/getEveryYearStuCountBySchoolId")
    @ApiOperation("根据驾校ID查询学员每年报名数")
    public ResponsePageInfo getEveryYearStuCountBySchoolId(@ModelAttribute TmsBmYearListDTO yearListDTO) {
        List<TmsBmCountVo> list = studentInfoService.getEveryYearStuCountBySchoolId(yearListDTO);
        ResponsePageInfo<TmsBmCountVo> reusltList = toResponsePageInfo(list);
        Map<String,Integer> map = new HashMap<String,Integer>();
        int total = list.stream().mapToInt(TmsBmCountVo::getStuCount).sum();
        map.put("total",total);
        reusltList.setData(map);
        return reusltList;
    }


    /**
     * 根据学员id获取电子教练日志
     * @return
     */
    @GetMapping("/getTmsStudentTeachLogById")
    @ApiOperation("根据学员id获取电子教学日志")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "当前页码", dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize", value = "每页数据量", dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<TmsStudentTeachLogVo> getTmsStudentTeachLogById(TmsStudentInfoIdDTO studentInfoIdDTO) {
        startPage();
        List<TmsStudentTeachLogVo> teachLogVoList = studentInfoService.getTmsStudentTeachLogById(studentInfoIdDTO);
        return toResponsePageInfo(teachLogVoList);
    }


    /**
     * 根据学员id和classId获取电子教学日志照片
     * @return
     */
    @GetMapping("/getTmsStudentPhotoById")
    @ApiOperation("根据学员id和classId获取电子教学日志照片")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "当前页码", dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize", value = "每页数据量", dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<TmsStudentPhotoVo> getTmsStudentPhotoById(TmsStudentInfoPhotoDTO studentInfoPhotoDTO) {
        startPage();
        List<TmsStudentPhotoVo> studentPhotoList = studentInfoService.getTmsStudentPhotoById(studentInfoPhotoDTO);
        return toResponsePageInfo(studentPhotoList);
    }


    /**
     * 厦门根据驾校ID获取名额
     */
    @GetMapping("/getXmBmLimit")
    @ApiOperation("厦门根据驾校ID获取名额")
    public Response getXmBmLimit(TmsBmDTO bmDTO) {
        return Response.success(studentInfoService.getXmBmLimit(bmDTO));
    }


    /**
     * 福州根据驾校ID获取名额
     */
    @GetMapping("/getFzBmLimit")
    @ApiOperation("福州根据驾校ID获取名额")
    public Response getFzBmLimit(TmsBmDTO bmDTO) {
        return Response.success(studentInfoService.getFzBmLimit(bmDTO));
    }



    /**
     * 根据学员身份证与手机号获取极速登录密码
     */
    @GetMapping("/getPasswordByIdcard")
    @ApiOperation("根据学员身份证与手机号获取极速登录密码")
    public Response getPasswordByIdcard(TmsIdcardPhoneDTO idcardPhoneDTO) {
        return Response.success(studentInfoService.getPasswordByIdcard(idcardPhoneDTO));
    }




}














