package com.miaxis.tms.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.miaxis.common.annotation.DataSource;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.enums.DataSourceTypeEnum;
import com.miaxis.common.utils.StringUtils;
import com.miaxis.tms.domain.TmsCoachInfo;
import com.miaxis.tms.dto.*;
import com.miaxis.tms.mapper.TmsCoachInfoMapper;
import com.miaxis.tms.service.ITmsCoachInfoService;
import com.miaxis.tms.vo.TmsCoachInfoVo;
import com.miaxis.tms.vo.TmsPasswordVo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * <p>
 * 学员基本信息表 服务实现类
 * </p>
 *
 * @author ${author}
 * @since 2021-03-09
 */
@Service
@DataSource(value = DataSourceTypeEnum.NEWGZPT)
public class TmsCoachInfoServiceImpl extends ServiceImpl<TmsCoachInfoMapper, TmsCoachInfo> implements ITmsCoachInfoService {


    @Resource
    TmsCoachInfoMapper mapper;

    private static Logger logger = LoggerFactory.getLogger(TmsCoachInfoServiceImpl.class);

    @Override
    public TmsCoachInfoVo getCoachInfoById(TmsCoachInfoIdDTO coaDto) {
        return  mapper.getCoachInfoById(coaDto);
    }

    @Override
    public TmsCoachInfoVo getCoachInfoByOpenid(TmsCoachInfoOpenidDTO coaOpenidDto) {
        return  mapper.getCoachInfoByOpenid(coaOpenidDto);
    }


    @Override
    public TmsCoachInfoVo getCoachBylogin(TmsCoachInfoDTO coaDto) {
        return mapper.getCoachBylogin(coaDto);
    }

    @Override
    public Response updateCoachPassword(TmsCoachInfoPwDTO coaPwDto) {

        TmsCoachInfoDTO coaDto = new TmsCoachInfoDTO();
        BeanUtils.copyProperties(coaPwDto,coaDto);
        TmsCoachInfoVo coachInfo = this.getCoachBylogin(coaDto);
        if(coachInfo==null) {
            Response response = new Response(502,"用户不存在或用户密码错误");
            return response;
        } else {
            int result = mapper.updateCoachPassword(coaPwDto);
            return Response.success(result);
        }
    }

    @Override
    public Response bindCoachOpenid(TmsCoachInfoBindDTO coachInfoBindDTO) {

        TmsCoachInfoDTO coaDto = new TmsCoachInfoDTO();
        BeanUtils.copyProperties(coachInfoBindDTO,coaDto);
        TmsCoachInfoVo coachInfoVo = mapper.getCoachBylogin(coaDto);  //查询帐号是否绑定过
        if(coachInfoVo!=null) {
            if(!StringUtils.isEmpty(coachInfoVo.getOpenid())) {
                Response response = new Response(502,"该教练员账号已绑定微信，请解绑后再次绑定。");
                return response;
            }
        } else {
            Response response = new Response(502,"用户不存在或用户密码错误");
            return response;
        }

        int result = mapper.updateCoachOpenid(coachInfoBindDTO);
        if(result>0) {
            coachInfoVo.setOpenid(coachInfoBindDTO.getOpenid());
            return Response.success(coachInfoVo);
        } else {
            return Response.success(null);
        }
    }

    @Override
    public Response unBindCoachOpenid(TmsCoachInfoDTO coachInfoDTO) {

        TmsCoachInfoBindDTO coachInfoBindDTO = new TmsCoachInfoBindDTO();
        BeanUtils.copyProperties(coachInfoDTO,coachInfoBindDTO);
        TmsCoachInfoVo coachInfoVo = mapper.getCoachBylogin(coachInfoDTO);  //查询帐号是否绑定过
        if(coachInfoVo==null) {
            Response response = new Response(502,"用户不存在或用户密码错误");
            return response;
        } else {
            int result = mapper.updateCoachOpenid(coachInfoBindDTO);
            return Response.success(result);
        }
    }

    @Override
    public TmsPasswordVo getPasswordByCoachIdcard(TmsIdcardPhoneDTO idcardPhoneDTO) {
        return mapper.getPasswordByCoachIdcard(idcardPhoneDTO);
    }


}
