package com.miaxis.tms.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.miaxis.common.annotation.DataSource;
import com.miaxis.common.enums.DataSourceTypeEnum;
import com.miaxis.common.utils.DateUtils;
import com.miaxis.common.utils.bean.BeanUtils;
import com.miaxis.tms.dto.*;
import com.miaxis.tms.mapper.TmsStudentInfoMapper;
import com.miaxis.tms.service.ITmsStudentInfoService;
import com.miaxis.tms.vo.*;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.sql.SQLException;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 学员基本信息表 服务实现类
 * </p>
 *
 * @author ${author}
 * @since 2021-03-09
 */
@Service
@DataSource(value = DataSourceTypeEnum.NEWGZPT)
public class TmsStudentInfoServiceImpl extends ServiceImpl<TmsStudentInfoMapper, TmsStudentInfoVo> implements ITmsStudentInfoService {


    @Resource
    TmsStudentInfoMapper mapper;



    @Override
    public List<TmsStudentInfoVo> getTmsAllStudentInfoList(TmsAllStudentInfoDTO aLLStudentInfoDTO) {
        return mapper.getTmsAllStudentInfoList(aLLStudentInfoDTO);
    }

    @Override
    public List<TmsStudentInfoVo> getTmsStudentInfoList(TmsStudentInfoDTO studentInfoDto) {
       List<TmsStudentInfoVo> list =  mapper.getTmsStudentInfoList(studentInfoDto);
        return list;
    }

    @Override
    public List<TmsStudentInfoVo> getTmsMyStudentInfoList(TmsStudentInfoDTO studentInfoDto) {
        List<TmsStudentInfoVo> list =  mapper.getTmsMyStudentInfoList(studentInfoDto);
        return list;
    }



    @Override
    public List<TmsStudentInfoTempVo> getTmsStudentInfoTempList(TmsStudentInfoTempDTO studentInfoTempDto) {
        List<TmsStudentInfoTempVo> list =  mapper.getTmsStudentInfoTempList(studentInfoTempDto);
        return list;
    }

    @Override
    public List<TmsStudentInfoTempVo> getTmsMyStudentInfoTempList(TmsStudentInfoTempDTO studentInfoTempDto) {
        List<TmsStudentInfoTempVo> list =  mapper.getTmsMyStudentInfoTempList(studentInfoTempDto);
        return list;
    }

    @Override
    public TmsStudentInfoIdVo getTmsStudentInfoById(TmsStudentInfoIdDTO stuIdDTO) {
        //台州
        if("3310".equals(stuIdDTO.getCity())){
            return mapper.getTzTmsStudentInfoById(stuIdDTO);
        } else { //福建其他地区
            return mapper.getTmsStudentInfoById(stuIdDTO);
        }
    }


    @Override
    public TmsStudentInfoIdVo getTmsStudentInfoTempById(TmsStudentInfoIdDTO stuIdDTO) {
        return mapper.getTmsStudentInfoTempById(stuIdDTO);
    }

    @Override
    public int upStuAppCoachIdById(TmsStudentInfoQrDTO studentInfoQrDTO) {
        return mapper.upStuAppCoachIdById(studentInfoQrDTO);
    }

    @Override
    public List<TmsLogFaceVo> getTmsLogFaceListByStuId(TmsStudentInfoIdDTO studentInfoIdDTO) {
        return mapper.getTmsLogFaceListByStuId(studentInfoIdDTO);
    }

    @Override
    public List<TmsSignVo> getTmsSignListByStuId(TmsStudentInfoIdDTO studentInfoIdDTO) {
        return mapper.getTmsSignListByStuId(studentInfoIdDTO);
    }


    @Override
    public TmsBmVo getStatisticsStuCountBySchoolId(TmsBmDTO bmDTO) throws SQLException {

        TmsBmDayDTO dayDTO = new TmsBmDayDTO();
        BeanUtils.copyProperties(bmDTO,dayDTO);

        dayDTO.setDay(0);
        TmsBmCountVo yDay = mapper.getDayStuTempCountBySchoolId(dayDTO);
        TmsBmCountVo day = mapper.getDayStuCountBySchoolId(dayDTO);

        dayDTO.setDay(1);
        TmsBmCountVo yesterday = mapper.getDayStuCountBySchoolId(dayDTO);

        TmsBmMonthDTO monthDTO = new TmsBmMonthDTO();
        BeanUtils.copyProperties(bmDTO,monthDTO);
        monthDTO.setMonth(0);
        TmsBmCountVo month = mapper.getMonthStuCountBySchoolId(monthDTO);

        monthDTO.setMonth(-1);
        TmsBmCountVo lastMonth = mapper.getMonthStuCountBySchoolId(monthDTO);

        monthDTO.setMonth(0);
        TmsBmCountVo year = mapper.getYearStuCountBySchoolId(monthDTO);
        monthDTO.setMonth(-12);
        TmsBmCountVo lastYear = mapper.getYearStuCountBySchoolId(monthDTO);


        TmsBmVo bmVo = new TmsBmVo();

        //今日预报名
        if (yDay!=null) {
            bmVo.setYday(yDay.getStuCount());
        } else {
            bmVo.setYday(0);
        }

        //今日报名
        if (day!=null) {
            bmVo.setDay(day.getStuCount());
        } else {
            bmVo.setDay(0);
        }
        //昨天报名
        if(yesterday!=null) {
            bmVo.setYesterday(yesterday.getStuCount());
        } else {
            bmVo.setYesterday(0);
        }
        //本月报名
        if(month!=null) {
            bmVo.setMonth(month.getStuCount());
        } else {
            bmVo.setMonth(0);
        }
        //上月报名
        if(lastMonth!=null) {
            bmVo.setLastMonth(lastMonth.getStuCount());
        } else {
            bmVo.setLastMonth(0);
        }
        //本年报名
        if(year!=null) {
            bmVo.setYear(year.getStuCount());
        } else {
            bmVo.setYear(0);
        }
        //去年报名
        if(lastYear!=null) {
            bmVo.setLastYear(lastYear.getStuCount());
        } else {
            bmVo.setLastYear(0);
        }

        return bmVo;
    }

    @Override
    public List<TmsBmCountVo> getEveryDayStuCountBySchoolId(TmsBmDayListDTO dayListDTO) {
        if(dayListDTO.getFieldType()==2){  //按学员字段排序
            dayListDTO.setField("stuCount");
        } else {  //默认按时间字段排序
            dayListDTO.setField("to_char(tso_applydate, 'yyyy-MM-dd')");
        }

        if(dayListDTO.getSortType()==1){  //按正序
            dayListDTO.setSort("asc");
        } else {  //默认按时间字段排序
            dayListDTO.setSort("desc");
        }

        return mapper.getEveryDayStuCountBySchoolId(dayListDTO);
    }

    @Override
    public List<TmsBmCountVo> getEveryMonthStuCountBySchoolId(TmsBmMonthListDTO monthListDTO) {

        if(monthListDTO.getFieldType()==2){  //按学员字段排序
            monthListDTO.setField("stuCount");
        } else {  //默认按时间字段排序
            monthListDTO.setField("TO_CHAR(tso_applydate, 'yyyy-MM')");
        }

        if(monthListDTO.getSortType()==1){  //按正序
            monthListDTO.setSort("asc");
        } else {  //默认按时间字段排序
            monthListDTO.setSort("desc");
        }

        return mapper.getEveryMonthStuCountBySchoolId(monthListDTO);
    }

    @Override
    public List<TmsBmCountVo> getEveryYearStuCountBySchoolId(TmsBmYearListDTO yearListDTO) {

        if(yearListDTO.getFieldType()==2){  //按学员字段排序
            yearListDTO.setField("stuCount");
        } else {  //默认按时间字段排序
            yearListDTO.setField("TO_CHAR(tso_applydate, 'yyyy')");
        }

        if(yearListDTO.getSortType()==1){  //按正序
            yearListDTO.setSort("asc");
        } else {  //默认按时间字段排序
            yearListDTO.setSort("desc");
        }

        return mapper.getEveryYearStuCountBySchoolId(yearListDTO);
    }


    @Override
    public TmsStudentInfoIdVo getTmsStudentInfoApplyById(TmsStudentInfoApplyIdDTO studentInfoApplyIdDTO) {

        Date applyDate = DateUtils.parseDate(studentInfoApplyIdDTO.getApplyDate()) ;
        Date pointDate = DateUtils.parseDate("2022-04-25");

        if(applyDate.compareTo(pointDate)>=0){
            return mapper.getWzTmsStudentInfoById(studentInfoApplyIdDTO);
        } else {
            return mapper.getWzOldTmsStudentInfoById(studentInfoApplyIdDTO);
        }

    }

    @Override
    public List<TmsStudentTeachLogVo> getTmsStudentTeachLogById(TmsStudentInfoIdDTO studentInfoIdDTO) {
        return mapper.getTmsStudentTeachLogById(studentInfoIdDTO);
    }


    @Override
    public List<TmsStudentPhotoVo> getTmsStudentPhotoById(TmsStudentInfoPhotoDTO studentInfoPhotoDTO) {
        return mapper.getTmsStudentPhotoById(studentInfoPhotoDTO);
    }


    @Override
    public TmsBmLimitVo getXmBmLimit(TmsBmDTO tmsBmDTO) {
        return mapper.getXmBmLimit(tmsBmDTO);
    }


    @Override
    public TmsFzLimitVo getFzBmLimit(TmsBmDTO bmDTO) {
        return mapper.getFzBmLimit(bmDTO);
    }


    @Override
    public TmsPasswordVo getPasswordByIdcard(TmsIdcardPhoneDTO idcardPhoneDTO) {
        return mapper.getPasswordByIdcard(idcardPhoneDTO);
    }

}
